# gwemlightcurves
Gravitational-wave Electromagnetic Lightcurves

https://gwemlightcurves.github.io/


################################
->When installing Multinest, make sure to:
export LD_LIBRARY_PATH=/home/user/MultiNest/lib/:$LD_LIBRARY_PATH
echo 'export_LD_LIBRARY_PATH=/home/user/MultiNest/lib/:$LD_LIBRARY_PATH' >>/home/user/.bashrc

################################
